<?php
/**
 * Thankyou page
 *
 * @author      WooThemes
 * @package     WooCommerce/Templates
 * @version     2.2.0
 */

if ( ! defined( 'ABSPATH' ) ) {
    exit; // Exit if accessed directly
}

if ( $order ) : ?>

    <?php if ( $order->has_status( 'failed' ) ) : ?>

        <p class="woocommerce-message"><?php esc_html_e( 'Unfortunately your order cannot be processed as the originating bank/merchant has declined your transaction.', 'burst' ); ?></p>

        <p class="woocommerce-message"><?php
            if ( is_user_logged_in() )
                esc_html_e( 'Please attempt your purchase again or go to your account page.', 'burst' );
            else
                esc_html_e( 'Please attempt your purchase again.', 'burst' );
        ?></p>

        <p class="woocommerce-message">
            <a href="<?php echo esc_url( $order->get_checkout_payment_url() ); ?>" class="button pay"><?php esc_html_e( 'Pay', 'burst' ) ?></a>
            <?php if ( is_user_logged_in() ) : ?>
                <a href="<?php echo esc_url( get_permalink( wc_get_page_id( 'myaccount' ) ) ); ?>" class="button pay"><?php esc_html_e( 'My Account', 'burst' ); ?></a>
            <?php endif; ?>
        </p>

    <?php else : ?>

        <p class="woocommerce-message"><?php echo apply_filters( 'woocommerce_thankyou_order_received_text', esc_html__( 'Thank you. Your order has been received.', 'burst' ), $order ); ?></p>

        <ul class="order_details clearfix">
            <li class="order">
                <span><?php esc_html_e( 'Order:', 'burst' ); ?></span>
                <p><?php echo esc_html($order->get_order_number()); ?></p>
            </li>
            <li class="date">
                <span><?php esc_html_e( 'Date:', 'burst' ); ?></span>
                <p><?php echo esc_html(date_i18n( get_option( 'date_format' ), strtotime( $order->order_date ) )); ?></p>
            </li>
            <li class="total">
                <span><?php esc_html_e( 'Total:', 'burst' ); ?></span>
                <p>
					<?php echo wp_kses($order->get_formatted_order_total(), array(
						'span' => array(
							'class' => true,
							'id' => true,
							'title' => true
						)
					)); ?>
				</p>
            </li>
            <?php if ( $order->payment_method_title ) : ?>
            <li class="method">
                <span><?php esc_html_e( 'Payment method:', 'burst' ); ?></span>
                <p><?php echo esc_html($order->payment_method_title); ?></p>
            </li>
            <?php endif; ?>
        </ul>
        <div class="clear"></div>

    <?php endif; ?>

    <div class="order-details-wrapper">
        <?php do_action( 'woocommerce_thankyou_' . $order->payment_method, $order->id ); ?>
        <?php do_action( 'woocommerce_thankyou', $order->id ); ?>
    </div>

<?php else : ?>

    <p class="message"><?php echo apply_filters( 'woocommerce_thankyou_order_received_text', esc_html__( 'Thank you. Your order has been received.', 'burst' ), null ); ?></p>

<?php endif; ?>